@@ -34,6 +34,9 @@ hanr_emd <- function(noise = 0.1, trials = 5) {
   obj$noise <- noise
   obj$trials <- trials
 
+  hutils <- harutils()
+  obj$har_outliers_check <- hutils$har_outliers_checks_highgroup
+
   class(obj) <- append("hanr_emd", class(obj))
   return(obj)
 }
